@@ -8,12 +8,20 @@ import shutil
 import logging
 import textwrap
 from glob import glob
-from zipfile import ZipFile, ZIP_DEFLATED
 from subprocess import Popen, PIPE, STDOUT
+from zipfile import ZipFile, ZipInfo, ZIP_DEFLATED
 
 ### Logging ###
-import logzero
-from logzero import logger
+from rich.logging import RichHandler
+
+logging.basicConfig(
+    level=logging.INFO,
+    format="%(message)s",
+    datefmt="[%X]",
+    handlers=[RichHandler(rich_tracebacks=True, markup=True)],
+)
+
+logger = logging.getLogger("rich")
 
 ### Parsing ###
 import yaml
@@ -30,8 +38,22 @@ uid_pattern = r"RequestUUID = ([A-z0-9-]+)"
 status_pattern = r"(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2} \+\d{4}) ([A-z0-9-]+) (success|invalid|in progress)(?: (\d)\s+(Package (?:Approved|Invalid)))?"  # noqa: E501
 
 
-class AliasedGroup(click.Group):
+class PermZipFile(ZipFile):
+    def extract(self, member, path=None, pwd=None):
+        if not isinstance(member, ZipInfo):
+            member = self.getinfo(member)
 
+        if path is None:
+            path = os.getcwd()
+
+        ret_val = self._extract_member(member, path, pwd)
+        attr = member.external_attr >> 16
+        os.chmod(ret_val, attr)
+
+        return ret_val
+
+
+class AliasedGroup(click.Group):
     def get_command(self, ctx, cmd_name):
         rv = click.Group.get_command(self, ctx, cmd_name)
         if rv is not None:
@@ -69,7 +91,7 @@ def zipdir(zipname, dirname):
             path = os.path.join(root, fname)
             total += os.path.getsize(path)
 
-    z = ZipFile(zipname, "w", ZIP_DEFLATED)
+    z = PermZipFile(zipname, "w", ZIP_DEFLATED)
 
     current = 0
     with tqdm(total=total, unit_scale=True, unit="B") as pbar:
@@ -85,10 +107,18 @@ def zipdir(zipname, dirname):
 
 @click.group(cls=AliasedGroup)
 @click.pass_context
-@click.argument("project", required=True, type=str)
-@click.option("-c", "--config", default="config.yaml", type=str)
-@click.option("-d/-nd", "--debug/--no-debug", default=False,
-              help="Print debug information or only regular output")
+@click.argument(
+    "project",
+    required=True,
+    type=click.Path(exists=True, dir_okay=False, resolve_path=True),
+)
+@click.option(
+    "-c",
+    "--config",
+    required=True,
+    type=click.Path(exists=True, dir_okay=False, resolve_path=True),
+)
+@click.option("-d", "--debug", is_flag=True, help="Print debug information if given")
 def cli(ctx, project, config, debug):
     """A utility script for quickly and automatically notarizing Ren'Py applications for macOS.
 
@@ -106,21 +136,13 @@ def cli(ctx, project, config, debug):
     """
     ctx.ensure_object(dict)
 
-    logzero.loglevel(logging.DEBUG if debug else logging.INFO)
+    logger.setLevel(logging.DEBUG if debug else logging.INFO)
 
     ctx.obj["debug"] = debug
 
     if not project.endswith(".zip"):
         project += ".zip"
 
-    if not os.path.exists(project):
-        logger.error("The path to the project is incorrect.")
-        sys.exit(1)
-
-    if not os.path.exists(config):
-        logger.error("The path to the config file is incorrect.")
-        sys.exit(1)
-
     ctx.obj["project"] = os.path.splitext(project)[0]
 
     with open(config, "r") as f:
@@ -138,10 +160,12 @@ def unpack_app(ctx):
     folder_name = ctx.obj["project"]
 
     if os.path.isdir(folder_name):
-        logger.error("Directory '{}' already exists, please remove it.".format(folder_name))
+        logger.error(
+            "Directory '{}' already exists, please remove it.".format(folder_name)
+        )
         sys.exit(1)
 
-    with ZipFile(zip_file, "r") as f:
+    with PermZipFile(zip_file, "r") as f:
         for member in tqdm(f.infolist()):
             f.extract(member, folder_name)
 
@@ -151,7 +175,9 @@ def unpack_app(ctx):
 def sign_app(ctx):
     logger.info("Signing App")
     with open("entitlements.plist", "w") as f:
-        f.write(textwrap.dedent("""
+        f.write(
+            textwrap.dedent(
+                """
             <?xml version="1.0" encoding="UTF-8"?>
             <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
             <plist version="1.0">
@@ -159,20 +185,24 @@ def sign_app(ctx):
                     <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
                     <true/>
                 </dict>
-            </plist>"""))
+            </plist>"""
+            )
+        )
 
     app_path = sorted(glob(os.path.join(ctx.obj["project"], "*.app")))[0]
 
-    cmd = ["codesign",
-           "--entitlements=entitlements.plist",
-           "--options=runtime",
-           "--timestamp",
-           "--verbose",
-           "-s {}".format(ctx.obj["config"]["identity"]),
-           "-f",
-           "--deep",
-           "--no-strict",
-           app_path]
+    cmd = [
+        "codesign",
+        "--entitlements=entitlements.plist",
+        "--options=runtime",
+        "--timestamp",
+        "--verbose",
+        "-s {}".format(ctx.obj["config"]["identity"]),
+        "-f",
+        "--deep",
+        "--no-strict",
+        app_path,
+    ]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -183,7 +213,10 @@ def sign_app(ctx):
         logger.debug(str(line.strip(), "utf-8"))
 
     if proc.returncode:
-        logger.error("An error occured while signing the app, run with --debug for more details.")
+        logger.error(
+            "An error occured while signing the app, run with --debug for more details."
+        )
+        sys.exit(1)
 
 
 @cli.command()
@@ -196,14 +229,16 @@ def notarize_app(ctx):
 
     zipdir(zip_file, app_path)
 
-    cmd = ["xcrun",
-           "altool",
-           ctx.obj["config"]["altool_extra"],
-           "-u {}".format(ctx.obj["config"]["apple_id"]),
-           "-p {}".format(ctx.obj["config"]["password"]),
-           "--notarize-app",
-           "--primary-bundle-id {}".format(ctx.obj["config"]["bundle"]),
-           "-f {}".format(zip_file)]
+    cmd = [
+        "xcrun",
+        "altool",
+        ctx.obj["config"]["altool_extra"],
+        "-u {}".format(ctx.obj["config"]["apple_id"]),
+        "-p {}".format(ctx.obj["config"]["password"]),
+        "--notarize-app",
+        "--primary-bundle-id {}".format(ctx.obj["config"]["bundle"]),
+        "-f {}".format(zip_file),
+    ]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -219,9 +254,12 @@ def notarize_app(ctx):
             uid = m.group(1)
 
     if proc.returncode:
-        logger.error("An error occured while notarizing the app, run with --debug for more details.")
+        logger.error(
+            "An error occured while notarizing the app, run with --debug for more details."
+        )
+        sys.exit(1)
 
-    logger.info("The app was submitted. The UID is: {}".format(uid))
+    logger.info("The app was submitted. The UID is: '{}'".format(uid))
 
     return uid
 
@@ -232,10 +270,7 @@ def staple_app(ctx):
     logger.info("Stapling App")
     app_path = sorted(glob(os.path.join(ctx.obj["project"], "*.app")))[0]
 
-    cmd = ["xcrun",
-           "stapler",
-           "staple",
-           app_path]
+    cmd = ["xcrun", "stapler", "staple", app_path]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -246,21 +281,26 @@ def staple_app(ctx):
         logger.debug(str(line.strip(), "utf-8"))
 
     if proc.returncode:
-        logger.error("An error occured while stapling the notarization ticket to the app, run with --debug for more details.")  # noqa: E501
+        logger.error(
+            "An error occured while stapling the notarization ticket to the app, run with --debug for more details."
+        )
+        sys.exit(1)
 
 
 @cli.command()
 @click.pass_context
 def pack_dmg(ctx):
     logger.info("Packing DMG")
-    cmd = ["hdiutil",
-           "create",
-           "-fs HFS+",
-           "-format UDBZ",
-           "-ov",
-           "-volname {}".format(ctx.obj["project"]),
-           "-srcfolder {}".format(ctx.obj["project"]),
-           "{}.dmg".format(ctx.obj["project"])]
+    cmd = [
+        "hdiutil",
+        "create",
+        "-fs HFS+",
+        "-format UDBZ",
+        "-ov",
+        "-volname {}".format(ctx.obj["project"]),
+        "-srcfolder {}".format(ctx.obj["project"]),
+        "{}.dmg".format(ctx.obj["project"]),
+    ]
     cmd = " ".join(cmd)
 
     logger.info("Running hdiutil")
@@ -269,17 +309,22 @@ def pack_dmg(ctx):
         logger.debug(str(line.strip(), "utf-8"))
 
     if proc.returncode:
-        logger.error("An error occured while packing the DMG, run with --debug for more details.")
+        logger.error(
+            "An error occured while packing the DMG, run with --debug for more details."
+        )
+        sys.exit(1)
 
 
 @cli.command()
 @click.pass_context
 def sign_dmg(ctx):
     logger.info("Signing DMG")
-    cmd = ["codesign",
-           "--timestamp",
-           "-s {}".format(ctx.obj["config"]["identity"]),
-           "-f {}.dmg".format(ctx.obj["project"])]
+    cmd = [
+        "codesign",
+        "--timestamp",
+        "-s {}".format(ctx.obj["config"]["identity"]),
+        "-f {}.dmg".format(ctx.obj["project"]),
+    ]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -290,21 +335,26 @@ def sign_dmg(ctx):
         logger.debug(str(line.strip(), "utf-8"))
 
     if proc.returncode:
-        logger.error("An error occured while signing the DMG, run with --debug for more details.")
+        logger.error(
+            "An error occured while signing the DMG, run with --debug for more details."
+        )
+        sys.exit(1)
 
 
 @cli.command()
 @click.pass_context
 def notarize_dmg(ctx):
     logger.info("Notarizing DMG")
-    cmd = ["xcrun",
-           "altool",
-           ctx.obj["config"]["altool_extra"],
-           "-u {}".format(ctx.obj["config"]["apple_id"]),
-           "-p {}".format(ctx.obj["config"]["password"]),
-           "--notarize-app",
-           "--primary-bundle-id {}.dmg".format(ctx.obj["config"]["bundle"]),
-           "-f {}.dmg".format(ctx.obj["project"])]
+    cmd = [
+        "xcrun",
+        "altool",
+        ctx.obj["config"]["altool_extra"],
+        "-u {}".format(ctx.obj["config"]["apple_id"]),
+        "-p {}".format(ctx.obj["config"]["password"]),
+        "--notarize-app",
+        "--primary-bundle-id {}.dmg".format(ctx.obj["config"]["bundle"]),
+        "-f {}.dmg".format(ctx.obj["project"]),
+    ]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -320,9 +370,12 @@ def notarize_dmg(ctx):
             uid = m.group(1)
 
     if proc.returncode:
-        logger.error("An error occured while notarizing the DMG, run with --debug for more details.")
+        logger.error(
+            "An error occured while notarizing the DMG, run with --debug for more details."
+        )
+        sys.exit(1)
 
-    logger.info("The DMG was submitted. The UID is: {}".format(uid))
+    logger.info("The DMG was submitted. The UID is: '{}'".format(uid))
 
     return uid
 
@@ -331,10 +384,7 @@ def notarize_dmg(ctx):
 @click.pass_context
 def staple_dmg(ctx):
     logger.info("Stapling DMG")
-    cmd = ["xcrun",
-           "stapler",
-           "staple",
-           "{}.dmg".format(ctx.obj["project"])]
+    cmd = ["xcrun", "stapler", "staple", "{}.dmg".format(ctx.obj["project"])]
     if ctx.obj["debug"]:
         cmd.append("--verbose")
     cmd = " ".join(cmd)
@@ -345,7 +395,10 @@ def staple_dmg(ctx):
         logger.debug(str(line.strip(), "utf-8"))
 
     if proc.returncode:
-        logger.error("An error occured while stapling the notarization ticket to the DMG, run with --debug for more details.")  # noqa: E501
+        logger.error(
+            "An error occured while stapling the notarization ticket to the DMG, run with --debug for more details."
+        )
+        sys.exit(1)
 
 
 @cli.command()
@@ -353,12 +406,14 @@ def staple_dmg(ctx):
 @click.option("-uid", help="The UID to check the status for", type=str)
 def status(ctx, uid):
     if not uid:
-        cmd = ["xcrun",
-               "altool",
-               ctx.obj["config"]["altool_extra"],
-               "-u {}".format(ctx.obj["config"]["apple_id"]),
-               "-p {}".format(ctx.obj["config"]["password"]),
-               "--notarization-history 0"]
+        cmd = [
+            "xcrun",
+            "altool",
+            ctx.obj["config"]["altool_extra"],
+            "-u {}".format(ctx.obj["config"]["apple_id"]),
+            "-p {}".format(ctx.obj["config"]["password"]),
+            "--notarization-history 0",
+        ]
         cmd = " ".join(cmd)
 
         logger.info("Retrieving general status information")
@@ -379,18 +434,23 @@ def status(ctx, uid):
                 divider_found = True
 
         if proc.returncode:
-            logger.error("An error occured while fetching the status, run with --debug for more details.")
+            logger.error(
+                "An error occured while fetching the status, run with --debug for more details."
+            )
+            sys.exit(1)
 
         latest_entry = sorted(data, key=lambda x: x[0], reverse=True)[0]
         latest_id = latest_entry[1]
 
-    cmd = ["xcrun",
-           "altool",
-           ctx.obj["config"]["altool_extra"],
-           "-u {}".format(ctx.obj["config"]["apple_id"]),
-           "-p {}".format(ctx.obj["config"]["password"]),
-           "--notarization-info {}".format(uid or latest_id),
-           "--output-format json"]
+    cmd = [
+        "xcrun",
+        "altool",
+        ctx.obj["config"]["altool_extra"],
+        "-u {}".format(ctx.obj["config"]["apple_id"]),
+        "-p {}".format(ctx.obj["config"]["password"]),
+        "--notarization-info {}".format(uid or latest_id),
+        "--output-format json",
+    ]
     cmd = " ".join(cmd)
 
     logger.info("Retrieving status details for {}".format(uid or latest_id))
@@ -403,12 +463,18 @@ def status(ctx, uid):
             logger.debug(line)
         data += line
 
+    if proc.returncode:
+        logger.error(
+            "An error occured while fetching the status, run with --debug for more details."
+        )
+        sys.exit(1)
+
     data = json.loads(data)
 
     try:
         status = data["notarization-info"]["Status"]
-    except:  # noqa: E722
-        logger.error("The UID either does not exist or was not submitted yet.")
+    except Exception:
+        logger.exception("The UID either does not exist or was not submitted yet.")
         return
 
     if status == "success":
@@ -417,10 +483,12 @@ def status(ctx, uid):
         logger.info("The notarization is in progress.")
     else:
         logger.error("The notarization failed.")
-        logger.error("The log file can be accessed here: {}".format(data["notarization-info"]["LogFileURL"]))
-
-    if proc.returncode:
-        logger.error("An error occured while fetching the status, run with --debug for more details.")
+        logger.error(
+            "The log file can be accessed here: {}".format(
+                data["notarization-info"]["LogFileURL"]
+            )
+        )
+        sys.exit(1)
 
     return status
 
@@ -467,8 +535,12 @@ def full_run(ctx):
     os.remove("{}-app.zip".format(ctx.obj["project"]))
     shutil.rmtree(ctx.obj["project"])
 
-    logger.info("Success! The file {}.dmg is now fully notarized and ready to be shipped.".format(ctx.obj["project"]))
+    logger.info(
+        "[green]Success![/green] The file [salmon]{}.dmg[/salmon] is now fully notarized and ready to be shipped.".format(
+            ctx.obj["project"]
+        )
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
